Installation
============


The easiest method is to install directly from pypi using pip::

  pip install python-logstash-async


If you prefer, you can download python-logstash-async and install it
directly from source::

    $ python setup.py install
